package VMOMI::FaultToleranceCpuIncompatible;
use parent 'VMOMI::CpuIncompatible';

use strict;
use warnings;

our @class_ancestors = ( 
    'CpuIncompatible',
    'VirtualHardwareCompatibilityIssue',
    'VmConfigFault',
    'VimFault',
    'MethodFault',
);

our @class_members = ( 
    ['model', 'boolean', 0, ],
    ['family', 'boolean', 0, ],
    ['stepping', 'boolean', 0, ],
);

sub get_class_ancestors {
    return @class_ancestors;
}

sub get_class_members {
    my $class = shift;
    my @super_members = $class->SUPER::get_class_members();
    return (@super_members, @class_members);
}

1;
